function AlwaysTrue()
	return true
end

-- eigener Held, ohne unit-Zuordnung
-- StartTurnAction; Count=1
function CreateHero()
	local hero = NewHero()
	hero.portrait = "/Game/Gui/Common/Heroes/generic_standin.generic_standin"
	hero.name = "Matteo_FastDeployment"
	hero.extra_traits = {UnitTrait.FastDeployment}
	local action = world:MakeNewHeroAction(0, hero)
	world:Exec(action)
end


-- Hilfsfunktionen
function FindItemInTable(table, item)
	for index,i in ipairs(table) do
		if i == item then
			return index 
		end
	end
	return -1
end

function IsItemInTable(table, item)
	return FindItemInTable(table, item) ~= -1
end

function AddEquipment(player_id, unit_type, quantity, category)
	local player = world:GetPlayer(player_id)
	local equipment = player.equipment
	local type = GetUnitType(unit_type)
	local eq = equipment[type]
	if (eq == nil) then
		eq = NewEquipment()
		eq.category = category
		equipment[type] = eq
	end
	eq.quantity = eq.quantity + quantity
	player.equipment = equipment
end

-- Depot erobern
-- ntig im Editor unter Trigger:
-- Count: 0
-- Condition kann leer bleiben
-- Actions: CaptureFlagAction
-- Function: OnCaptureDepot

Depot = {{6,17}}
string = "General, wir haben ein Ausrüstungslager der Briten erobert."
captured_depots = {}

function OnCaptureDepot(action)
	if IsItemInTable(captured_depots, action.flag) then return end
	if (action.new_owner == 0 and IsItemInTable(Depot, action.flag)) then
		AddEquipment(0, "CruiserMkIV", 10, captured)
		AddEquipment(0, "2pdrportee", 10, captured)
		AddEquipment(0, "BL7-2inch", 10, captured)
		TutorialMessage(string)					
		table.insert(captured_depots, action.flag)
	else
		return
	end
end


-- Feinde tauchen im Osten auf
normal_wave_turns = {3}

-- *** Hex zones ***
-- Spawn zones
-- When spawning a set of units, the script will scan spawn zones hex by hex, in the order specified, and spawn units in free hexes it finds
-- If the script runs out of hexes, the remainder of the units will not be spawned.
sr_spawn_zoneS = {{30,2},{29,3},{30,4},{30,8},{30,9},{30,10},{30,5},{30,6},{30,7},{30,1},{30,11},{30,15}}

-- *** Enemy waves ***
-- Each unit set is a list of blocks in the following format: { "<Unit ID>", "<Transport ID>", overstrength, experience }
-- If no organic transport is needed, its respective field should be empty string ("").

sr_wave1 = { {"AUInfantry", "UniversalCarrier", 0, 900}, {"AUHWInf", "UniversalCarrier", 0, 900}, {"CruiserMkIV", "", 0, 900}, {"AUInfantry", "UniversalCarrier", 0, 900}, {"AUHWInf", "UniversalCarrier", 0, 900}, {"CruiserMkIV", "", 0, 800}, {"QF25pdrATY", "UniversalCarrier", 0, 900}, {"VickersAA", "UniversalCarrier", 0, 800} }

-- There can be any number of waves in this list, the game will pick a random one every time
sr_waves = {sr_wave1}

-- There can be any number of zones in this list, the game will pick a random one every time
sr_zones = {sr_spawn_zoneS}

function SpawnWave(player, zone, units)
	local owner = world:GetPlayer(player)
	local cur_hex = 1

	-- Iterate through all units and spawn each one
	for _,u in ipairs(units) do
		-- Find the next vacant hex in the zone
		while zone[cur_hex] do
			hex = world:GetHex(zone[cur_hex])
			if hex:GetUnit(0) == nil then break end -- found
			cur_hex = cur_hex + 1
		end

		-- If we have run out of hexes in the zone, stop
		if not zone[cur_hex] then return end

		-- Create the unit in the free hex we've found
		-- 1. Create and execute purchase action, use unit type, transport type and overstrength as parameters
		local create_action = world:MakePurchaseAction(owner, u[1], u[2], u[3])
		create_action.auxiliary = false -- spawn core units
		create_action.cost = 0 -- don't take money for units we generate
		create_action.faction = owner.factions[1]  --set to first faction of owning player for created units
		world:Exec(create_action)

		-- 2. Create and execute deploy action, place the unit in the hex we've picked.
		local unit = world:GetUnit(create_action.id)
		deploy_action = world:MakeDeployAction(unit, zone[cur_hex])
		world:Exec(deploy_action)

		-- 3. Now modify the unit to set its experience to the value we need.
		unit.experience = u[4]
		
		-- 4. Now modify the unit to set its aggressiveness to the value we need.
		player_aggressiveness = { 10, 10, 10, 10 }
		unit.aggressiveness = player_aggressiveness[player+1]
	end
end

-- count=0, AlwaysTrue, Actions=NewRoundAction
function OnNewRound(action)
	-- On the first call, initialize the random generator
	if world.round == 1 then
		math.randomseed(world.seed)
	end

	-- Do we need to spawn a normal wave?
	local is_normal_wave = IsItemInTable(normal_wave_turns, world.round)

	-- If we don't need to spawn any normal or boss waves this turn then just finish
	if not is_normal_wave then return end

	-- Determine the player to get the next wave
	player = 1

	-- Determine the right zone and units to spawn
	local zone
	local units

	zone = sr_zones[ math.random( #sr_zones ) ] -- random normal SR zone
	units = sr_waves[ math.random( #sr_waves ) ] -- random normal SR wave

	-- Now spawn this wave!
	SpawnWave(player, zone, units)
	MessageBox("Achtung", "Die Feinde holen auf und bedrängen uns von Osten aus")					
end

